@@ -7,10 +7,11 @@ test_that("Test function createBaseTable()", {
   utils::data(rawDrugNamesCoOcEPILONT, package="epos")
   utils::data(rawDrugNamesCoOcEPISEM, package="epos")
   utils::data(rawDrugNamesCoOcFENICS, package="epos")
-  neurotable <- createBaseTable(coocepso = rawDrugNamesCoOcEpSO[1:150],
-    coocesso=rawDrugNamesCoOcESSO[1:150],
-    coocepi=rawDrugNamesCoOcEPILONT[1:150],
-    coocepisem=rawDrugNamesCoOcEPISEM[1:150],
-    coocfenics=rawDrugNamesCoOcFENICS[1:150])
+  suppressWarnings({neurotable <- createBaseTable(
+    coocepso = rawDrugNamesCoOcEpSO[1:250],
+    coocesso=rawDrugNamesCoOcESSO[1:250],
+    coocepi=rawDrugNamesCoOcEPILONT[1:250],
+    coocepisem=rawDrugNamesCoOcEPISEM[1:250],
+    coocfenics=rawDrugNamesCoOcFENICS[1:250])})
   expect_that(length(neurotable), equals(16))
 })
\ No newline at end of file
