@@ -4,6 +4,6 @@ context("test_readSecondLevelATC")
 test_that("Test function readSecondLevelATC()", {
   atchashsec <-
     readSecondLevelATC(
-    system.file("extdata", "drugbankatc-secondlevel.map", package = "epos"), "\t")
+    system.file("extdata", "atc-secondlevel.map", package = "epos"), "\t")
   expect_that(length(names(atchashsec)), equals(89))
 })
\ No newline at end of file
